@@ -1,8 +1,25 @@
-use clap::{Command, CommandFactory, Parser};
+pub mod keywords;
+
+use clap::{Command, CommandFactory, Parser, ValueEnum};
 use clap_complete::{generate, Generator, Shell};
 use std::io;
 use std::process::exit;
 
+#[derive(Debug, Copy, Clone, PartialEq, Eq, PartialOrd, Ord, ValueEnum)]
+pub enum HighlighterGroup {
+    Numbers,
+    Urls,
+    Pointers,
+    Dates,
+    Paths,
+    Quotes,
+    KeyValuePairs,
+    Uuids,
+    IpAddresses,
+    Processes,
+    Json,
+}
+
 #[derive(Parser)]
 #[command(name = "tspin")]
 #[command(author, version, about)]
@@ -27,7 +44,7 @@ pub struct Cli {
     #[clap(long = "config-path")]
     pub config_path: Option<String>,
 
-    /// Continuously listen to stdout from the provided command and prevent interrupt events (Ctrl + C) from reaching the command
+    /// Capture the output (stdout) of a command and view it in `less`
     #[clap(short = 'c', long = "listen-command", conflicts_with = "follow")]
     pub listen_command: Option<String>,
 
@@ -55,28 +72,24 @@ pub struct Cli {
     #[clap(long = "words-cyan", use_value_delimiter = true)]
     pub words_cyan: Vec<String>,
 
-    /// Disable the highlighting of all builtin keyword groups (booleans, severity and REST)
-    #[clap(long = "disable-builtin-keywords")]
-    pub disable_keyword_builtins: bool,
+    /// Enable specific highlighters
+    #[clap(long = "enable", value_enum, use_value_delimiter = true)]
+    pub enable: Vec<HighlighterGroup>,
 
-    /// Disable the highlighting of booleans and nulls
-    #[clap(long = "disable-booleans")]
-    pub disable_booleans: bool,
+    /// Disable specific highlighters
+    #[clap(long = "disable", value_enum, use_value_delimiter = true)]
+    pub disable: Vec<HighlighterGroup>,
 
-    /// Disable the highlighting of severity levels
-    #[clap(long = "disable-severity")]
-    pub disable_severity: bool,
-
-    /// Disable the highlighting of REST verbs
-    #[clap(long = "disable-rest")]
-    pub disable_rest: bool,
+    /// Disable the highlighting of all builtin keyword groups (booleans, nulls, log severities and common REST verbs)
+    #[clap(long = "no-builtin-keywords")]
+    pub no_builtin_keywords: bool,
 
     /// Suppress all output (for debugging and benchmarking)
     #[clap(long = "suppress-output", hide = true)]
     pub suppress_output: bool,
 
     /// Print completions to stdout
-    #[clap(long = "z-generate-shell-completions", hide = true)]
+    #[clap(long = "hidden-generate-shell-completions", hide = true)]
     pub generate_shell_completions: Option<String>,
 }
 
