@@ -1,15 +1,7 @@
-use crate::line_info::LineInfo;
-
 pub const OK: i32 = 0;
 pub const GENERAL_ERROR: i32 = 1;
 pub const MISUSE_SHELL_BUILTIN: i32 = 2;
 
-pub trait Highlight {
-    fn should_short_circuit(&self, line_info: &LineInfo) -> bool;
-    fn only_apply_to_segments_not_already_highlighted(&self) -> bool;
-    fn apply(&self, input: &str) -> String;
-}
-
 pub struct Error {
     pub exit_code: i32,
     pub message: String,
