@@ -5,8 +5,8 @@ set -e  # If any command fails, stop the script immediately
 full_version=$(cargo run -- -V)
 version_number=$(echo "$full_version" | awk '{print $2}')
 
-touch spin.adoc
+touch tspin.adoc
 
-asciidoctor -b manpage spin.adoc \
+asciidoctor -b manpage tspin.adoc \
   --destination=../man/ \
   --attribute release-version="$version_number"
\ No newline at end of file
